server_client_20150129_153254

### config2 : test_client_isolation

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 2.37970519066 sec | 5.70885109901 sec

Error message: Did not properly handle faulty client

Naarad report

### Metrics

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.295
server1-perf | latency | mean lt 0.33 | 0.357882086168
server1-perf | qps | mean lt 7.0 | 220.5
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | None
client1-perf | latency | mean lt 35.0 | None
client1-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None